"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyBindingManager = exports.keyBindingStore = void 0;
const electron_store_1 = __importDefault(require("electron-store"));
const schema = {
    toggleVoiceCapture: {
        type: 'string',
        default: 'CommandOrControl+Shift+E',
    },
};
exports.keyBindingStore = new electron_store_1.default({ name: 'keyBindings', schema });
const customBindings = [
    {
        label: 'Voice capture',
        command: 'voiceCapture',
        defaultShortcut: 'CommandOrControl+Shift+E',
        customShortcut: undefined,
    },
];
class KeyBindingManager {
    constructor(globalShortcut, onCommand) {
        this.globalShortcut = globalShortcut;
        this.onCommand = onCommand;
    }
    getKeyBindings() {
        return customBindings.map((binding) => {
            return {
                label: binding.label,
                command: binding.command,
                defaultShortcut: binding.defaultShortcut,
                customShortcut: exports.keyBindingStore.get(binding.command),
            };
        });
    }
    updateKeyBindings(bindings) {
        for (const command of Object.keys(bindings)) {
            // trim all spaces from shortcut
            const shortcut = bindings[command].replace(/\s/g, '');
            if (!customBindings.find((binding) => binding.command === command)) {
                console.error(`Unknown command ${command}`);
            }
            exports.keyBindingStore.set(command, shortcut);
        }
        this.bindAll();
    }
    bindAll() {
        this.globalShortcut.unregisterAll();
        const bindings = this.getKeyBindings();
        for (const binding of bindings) {
            const bindingToUse = binding.customShortcut && typeof binding.customShortcut === 'string'
                ? binding.customShortcut
                : binding.defaultShortcut;
            try {
                this.globalShortcut.register(bindingToUse, () => {
                    this.onCommand(binding.command);
                });
            }
            catch (error) {
                console.error('error registering global shortcut', error);
            }
        }
    }
}
exports.KeyBindingManager = KeyBindingManager;
//# sourceMappingURL=keyBindings.js.map