"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMenuTemplate = void 0;
function getMenuTemplate({ isMac, isSpellCheckerEnabled, onAction, }) {
    const template = [];
    const mainSubmenu = [];
    mainSubmenu.push({
        label: 'About',
        click: () => {
            onAction('about');
        },
    });
    if (isMac) {
        mainSubmenu.push({ type: 'separator' }, 
        // https://www.electronjs.org/docs/latest/api/menu#standard-menu-item-actions
        {
            role: 'hide',
        }, {
            role: 'hideOthers',
        });
    }
    mainSubmenu.push({ type: 'separator' }, { role: 'quit', label: 'Quit Tana' });
    template.push({
        label: isMac ? 'Tana' : 'File',
        submenu: mainSubmenu,
    }, {
        label: 'Edit',
        submenu: [
            { label: 'Find', accelerator: 'CmdOrCtrl+F', click: () => onAction('search') },
            { type: 'separator' },
            { role: 'selectAll' },
            { role: 'cut' },
            { role: 'copy' },
            { role: 'paste' },
            {
                role: 'pasteAndMatchStyle',
                accelerator: process.platform === 'darwin' ? 'Shift+Cmd+V' : 'Ctrl+Shift+V',
            },
        ],
    }, {
        label: 'View',
        submenu: [
            { role: 'reload' },
            { role: 'forceReload' },
            { role: 'toggleDevTools' },
            { type: 'separator' },
            { role: 'resetZoom' },
            { role: 'zoomIn' },
            { role: 'zoomOut' },
            { type: 'separator' },
            { role: 'togglefullscreen' },
        ],
    }, {
        label: 'History',
        submenu: [
            {
                label: 'Back',
                accelerator: 'CmdOrCtrl+[',
                click: () => {
                    onAction('back');
                },
            },
            {
                label: 'Forward',
                accelerator: 'CmdOrCtrl+]',
                click: () => {
                    onAction('forward');
                },
            },
        ],
    }, {
        label: 'Options',
        submenu: [
            {
                label: 'Toggle spellchecker',
                type: 'checkbox',
                click: () => onAction('toggleSpellCheck'),
                checked: isSpellCheckerEnabled,
            },
            {
                label: 'Customize keybindings',
                click: () => onAction('keyBindings'),
            },
        ],
    });
    if (isMac) {
        template.push({
            label: 'Window',
            submenu: [
                { role: 'minimize' },
                { role: 'zoom' },
                { type: 'separator' },
                { role: 'front' },
                { type: 'separator' },
                { role: 'window' },
            ],
        });
    }
    else {
        template.push({
            label: 'Window',
            submenu: [{ role: 'minimize' }, { role: 'zoom' }, { type: 'separator' }, { role: 'close' }],
        });
    }
    return template;
}
exports.getMenuTemplate = getMenuTemplate;
//# sourceMappingURL=menu.js.map